@@ -1,5 +1,5 @@
-from . import application
-from . import controller
+from .application import application
+from .controller import controller
 # from .logger import logger, ErrorLog
 from .config import configuration
 from .filter import filter
