@@ -1,10 +1,4 @@
-class configuration:
-    @staticmethod
-    def init(config, appPath):
-        configuration.config = config
-        configuration.default = deflautConfig()
-        configuration.appPath = appPath
-
+class _configuration(type):
     @staticmethod
     def __getattr__(name):
         value = None
@@ -14,6 +8,15 @@ class configuration:
             value = getattr(configuration.default, name).format(appPath=configuration.appPath)
         return value
 
+class configuration(metaclass=_configuration):
+    __metaclass__ = _configuration
+
+    @staticmethod
+    def init(config, appPath):
+        configuration.config = config
+        configuration.default = deflautConfig()
+        configuration.appPath = appPath
+
 class deflautConfig:
 
     middleware_list = []
